@@ -1,33 +1,24 @@
-import base64
 import os
 import signal
 import time
-from io import BytesIO
-from pathlib import Path
 from typing import Dict, List, Optional
 
-from PIL import Image
+from RPA.core.windows.locators import Locator, WindowsElement
+from RPA.core.windows.window import WindowMethods
 
+from RPA.Windows import utils
 from RPA.Windows.keywords import (
     ElementNotFound,
-    LibraryContext,
     WindowControlError,
     keyword,
     with_timeout,
 )
-from RPA.Windows import utils
-from .locators import Locator, WindowsElement
 
 if utils.IS_WINDOWS:
     import uiautomation as auto
-    import win32process
-    import win32api
-    import win32con
-    import win32ui
-    import win32gui
 
 
-class WindowKeywords(LibraryContext):
+class WindowKeywords(WindowMethods):
     """Keywords for handling Window controls"""
 
     @staticmethod
@@ -49,8 +40,8 @@ class WindowKeywords(LibraryContext):
         self,
         locator: Optional[Locator] = None,
         foreground: bool = True,
-        wait_time: float = None,
-        timeout: float = None,  # pylint: disable=unused-argument
+        wait_time: Optional[float] = None,
+        timeout: Optional[float] = None,  # pylint: disable=unused-argument
         main: bool = True,
     ) -> WindowsElement:
         """Controls the window defined by the locator.
@@ -105,8 +96,8 @@ class WindowKeywords(LibraryContext):
         self,
         locator: Optional[Locator] = None,
         foreground: bool = True,
-        wait_time: float = None,
-        timeout: float = None,
+        wait_time: Optional[float] = None,
+        timeout: Optional[float] = None,
     ) -> WindowsElement:
         """Get control of child window of the active window
         by locator.
@@ -164,7 +155,7 @@ class WindowKeywords(LibraryContext):
 
         utils.call_attribute_if_available(window.item, "SetFocus")
         utils.call_attribute_if_available(window.item, "SetActive")
-        window.item.MoveCursorToMyCenter(simulateMove=self.ctx.simulate_move)
+        window.item.MoveCursorToMyCenter(simulateMove=self.ctx.SIMULATE_MOVE)
         return window
 
     @keyword(tags=["window"])
@@ -251,11 +242,15 @@ class WindowKeywords(LibraryContext):
         return window
 
     @keyword(tags=["window"])
-    def list_windows(self, icons: bool = False) -> List[Dict]:
+    def list_windows(
+        self, icons: bool = False, icon_save_directory: Optional[str] = None
+    ) -> List[Dict]:
         """List all window element on the system.
 
         :param icons: on True dictionary will contain Base64
          string of the icon, default False
+        :param icon_save_directory: if set will save retrieved icons
+         into this filepath, by default icon files are not saved
         :return: list of dictionaries containing information
          about Window elements
 
@@ -271,58 +266,9 @@ class WindowKeywords(LibraryContext):
                 Log  Window process handle:${window}[handle]
             END
         """
-        windows = auto.GetRootControl().GetChildren()
-        process_list = utils.get_process_list()
-        win_list = []
-        for win in windows:
-            pid = win.ProcessId
-            fullpath = None
-            try:
-                handle = win32api.OpenProcess(win32con.PROCESS_ALL_ACCESS, False, pid)
-                fullpath = win32process.GetModuleFileNameEx(handle, 0)
-            except Exception as err:  # pylint: disable=broad-except
-                self.logger.info("Open process error in `List Windows`: %s", str(err))
-
-            info = {
-                "title": win.Name,
-                "pid": pid,
-                "name": process_list[pid] if pid in process_list else None,
-                "path": fullpath,
-                "handle": win.NativeWindowHandle,
-                "icon": self.get_icon(fullpath) if icons else None,
-            }
-            win_list.append(info)
-        return win_list
-
-    def get_icon(self, filepath: str) -> str:
-        image_string = None
-        executable_path = Path(filepath)
-        ico_x = win32api.GetSystemMetrics(win32con.SM_CXICON)
-        ico_y = win32api.GetSystemMetrics(win32con.SM_CYICON)
-
-        large, small = win32gui.ExtractIconEx(filepath, 0, 10)
-        if len(small) > 0:
-            win32gui.DestroyIcon(small[0])
-
-        hdc = win32ui.CreateDCFromHandle(win32gui.GetDC(0))
-        hbmp = win32ui.CreateBitmap()
-
-        hbmp.CreateCompatibleBitmap(hdc, ico_x, ico_y)
-        hdc = hdc.CreateCompatibleDC()
-
-        hdc.SelectObject(hbmp)
-
-        if len(large) > 0:
-            hdc.DrawIcon((0, 0), large[0])
-            result_image_file = f"icon_{executable_path.name}.bmp"
-            hbmp.SaveBitmapFile(hdc, result_image_file)
-            # signedIntsArray = hbmp.GetBitmapBits(True)
-            with Image.open(result_image_file) as img:
-                buffered = BytesIO()
-                img.save(buffered, format="PNG")
-                image_string = base64.b64encode(buffered.getvalue())
-            Path(result_image_file).unlink()
-        return image_string
+        return super().list_windows(
+            icons=icons, icon_save_directory=icon_save_directory
+        )
 
     @keyword(tags=["window"])
     def windows_run(self, text: str, wait_time: float = 3.0) -> None:
